==> pointpos_api-0.2.0.tar.gz: test/merchant_account_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for MerchantAccount
void main() {
  var instance = new MerchantAccount();

  group('test MerchantAccount', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // MerchantAccountPersonalDetails personalDetails (default value: null)
    test('to test the property `personalDetails`', () async {
      // TODO
    });

    // MerchantAccountBusinessInfo businessInfo (default value: null)
    test('to test the property `businessInfo`', () async {
      // TODO
    });

    // MerchantAccountIdentification identification (default value: null)
    test('to test the property `identification`', () async {
      // TODO
    });

    // MerchantAccountPublicProfile publicProfile (default value: null)
    test('to test the property `publicProfile`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: null)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.2.1.tar.gz: test/merchant_account_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for MerchantAccount
void main() {
  var instance = new MerchantAccount();

  group('test MerchantAccount', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // MerchantAccountPersonalDetails personalDetails (default value: null)
    test('to test the property `personalDetails`', () async {
      // TODO
    });

    // MerchantAccountBusinessInfo businessInfo (default value: null)
    test('to test the property `businessInfo`', () async {
      // TODO
    });

    // MerchantAccountIdentification identification (default value: null)
    test('to test the property `identification`', () async {
      // TODO
    });

    // MerchantAccountNpwp npwp (default value: null)
    test('to test the property `npwp`', () async {
      // TODO
    });

    // MerchantAccountPublicProfile publicProfile (default value: null)
    test('to test the property `publicProfile`', () async {
      // TODO
    });

    // MerchantAccountShift shift (default value: null)
    test('to test the property `shift`', () async {
      // TODO
    });

    // MerchantAccountEmailNotificationsSetting emailNotificationsSetting (default value: null)
    test('to test the property `emailNotificationsSetting`', () async {
      // TODO
    });

    // MerchantAccountCheckOutSetting checkOutSetting (default value: null)
    test('to test the property `checkOutSetting`', () async {
      // TODO
    });

    // bool deleted (default value: false)
    test('to test the property `deleted`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });


  });

}
